@@ -223,9 +223,9 @@ use Scalar::Util ();
 use AnyEvent ();
 use AnyEvent::Util ();
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
-sub OBSID() { 0x10000000000000 } # 2**52
+sub OBSID() { 2**52 }
 
 our $JSON = eval { require JSON::XS; JSON::XS:: }
           || do  { require JSON::PP; JSON::PP:: };
@@ -490,12 +490,15 @@ sub start {
 
       $wbuf .= "$cmd\n";
 
-      $self->{ww} ||= AE::io $fh, 1, sub {
+      my $wcb = sub {
          my $len = syswrite $fh, $wbuf;
          substr $wbuf, 0, $len, "";
          undef $self->{ww} unless length $wbuf;
       };
 
+      $wcb->();
+      $self->{ww} ||= AE::io $fh, 1, $wcb if length $wbuf;
+
       $cv
    };
 
